/*
 *           Vertex Model Assembler: V3D Primitives Palette
 */

#ifndef PRIMPALETTE_H
#define PRIMPALETTE_H

#include <sys/types.h>
#include <gtk/gtk.h>

#include "v3dmp.h"


/*
 *	V3D Primitives Palette Item:
 */
typedef struct {

	gint		type;		/* One of V3DMP_TYPE_* */
	gint		width,
			height;
	GdkPixmap	*pixmap;
	GdkBitmap	*mask;
	gchar		*description;	/* Tool tip description */
	gpointer	p;		/* Unrealized referance primitive */

} vma_primitives_palette_item_struct;


/*
 *	V3D Primitives Palette:
 */
typedef struct {

	gboolean	initialized;

	gpointer	core_ptr;
	gpointer	editor_ptr;

	GdkGC		*gc_fg,
			*gc_bg,
			*gc_selected_fg,
			*gc_selected_bg,
			*gc_insensitive_bg;

	GtkWidget	*toplevel,
			*palette;	/* GtkDrawingArea */

	vma_primitives_palette_item_struct **item;
	gint		selected_item,
			motion_item,
			total_items;

	GtkAdjustment	*adj;	/* Scroll position */

	guint		scroll_toid;	/* (guint)(-1) for none */

	gpointer	client_data;
	void		(*select_cb)(
		gpointer,	/* client_data */
		gint		/* Index number of item */
	);
	void		(*create_cb)(
		gpointer,       /* client_data */
		gint,		/* Primitive type, V3DMP_TYPE_* */
		gpointer	/* Referance primitive */
	);

} vma_primitives_palette_struct;


extern vma_primitives_palette_struct *VMAPrimPaletteNew(
	void *core_ptr, void *editor_ptr,
	GdkWindow *window,
	gpointer client_data,
	void (*select_cb)(gpointer, gint),
	void (*create_cb)(gpointer, gint, gpointer)
);
extern void VMAPrimPaletteSensitivity(
	vma_primitives_palette_struct *pp, gboolean sensitivity
);
extern void VMAPrimPaletteDelete(vma_primitives_palette_struct *pp);


#endif	/* PRIMPALETTE_H */
